Alignment enum

Alignment points relative to a 2D box.

Inheritance
Available extensions

Values

topLeft → const Alignment

The top-left corner.

const Alignment('top-left')
topCenter → const Alignment

The top edge, centered horizontally.

const Alignment('top-center')
topRight → const Alignment

The top-right corner.

const Alignment('top-right')
centerLeft → const Alignment

The center of the left edge.

const Alignment('center-left')
center → const Alignment

The center point.

const Alignment('center')
centerRight → const Alignment

The center of the right edge.

const Alignment('center-right')
bottomLeft → const Alignment

The bottom-left corner.

const Alignment('bottom-left')
bottomCenter → const Alignment

The bottom edge, centered horizontally.

const Alignment('bottom-center')
bottomRight → const Alignment

The bottom-right corner.

const Alignment('bottom-right')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The standard CSS value representing the alignment type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Alignment>
A constant List of the values in this enum, in order of their declaration.