AlwaysScrollableScrollPhysics constructor
const
AlwaysScrollableScrollPhysics()
Creates a scroll physics that always allows scrolling even if content fits.
Implementation
const AlwaysScrollableScrollPhysics();
Creates a scroll physics that always allows scrolling even if content fits.
const AlwaysScrollableScrollPhysics();