BannerType enum

Severity / intent type for Banner component.

Inheritance
Available extensions

Values

info → const BannerType

Informational alert (blue tint).

success → const BannerType

Success alert (green tint).

warning → const BannerType

Warning alert (yellow / amber tint).

error → const BannerType

Error / danger alert (red tint).

neutral → const BannerType

Neutral alert (grey tint).

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BannerType>
A constant List of the values in this enum, in order of their declaration.