BottomNavigationBarItem class
Represents an item in BottomNavigationBar.items.
Constructors
-
const
Properties
- classes → String?
-
Additional CSS classes applied to the item.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
Icon to display.
final
- key → Key?
-
An optional key for the item.
final
- label → String?
-
Text displayed below the icon.
final
- labelComponent → Component?
-
Custom label to display instead of label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → String?
-
Tooltip for the item which shows up on hover.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited