BottomNavigationBarLandscapeLayout enum
Refines the landscape layout of a bottom navigation bar.
Values
- spread → const BottomNavigationBarLandscapeLayout
-
The navigation bar's items are evenly spaced and spread out across the available width. Each item's label and icon are arranged in a column.
const BottomNavigationBarLandscapeLayout('navbar__spread-layout') - centered → const BottomNavigationBarLandscapeLayout
-
The navigation bar's items are evenly centered within the available width. Each item's label and icon are arranged in a column.
const BottomNavigationBarLandscapeLayout('navbar__centered-layout') - linear → const BottomNavigationBarLandscapeLayout
-
The navigation bar's items are evenly spaced. Each item's icon and label are lined up in a row instead of a column.
This layout is suitable on devices/screens that are wide enough (such as tablets and large desktop screens) in landscape orientation.
const BottomNavigationBarLandscapeLayout('navbar__linear-layout')
Properties
- className → String
-
The CSS class name representing the bottom navbar landscape layout.
example: 'navbar__linear-layout'
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BottomNavigationBarLandscapeLayout> - A constant List of the values in this enum, in order of their declaration.