className property
The CSS class name representing the bottom navbar landscape layout. example: 'navbar__linear-layout'
Implementation
final String className;
The CSS class name representing the bottom navbar landscape layout. example: 'navbar__linear-layout'
final String className;