BottomNavigationBarType enum

Defines BottomNavigationBar type.

Inheritance
Available extensions

Values

floating → const BottomNavigationBarType

The bottom navigation bar is elevated, centered on the screen, and has a smaller width than the screen width.

const BottomNavigationBarType('navbar__floating')
fixed → const BottomNavigationBarType

The bottom navigation bar is centered, extends across the entire width of the screen, and its items have fixed width.

const BottomNavigationBarType('navbar__fixed')
frostedGlass → const BottomNavigationBarType

The bottom navigation bar has an iOS-style frosted glass effect, is elevated, centered on the screen, and has a smaller width than the screen width.

const BottomNavigationBarType('navbar__frosted-glass')

Properties

className → String
The CSS class name representing the bottom navigation bar style. example: 'navbar__floating'
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BottomNavigationBarType>
A constant List of the values in this enum, in order of their declaration.