className property
The CSS class name representing the bottom navigation bar style. example: 'navbar__floating'
Implementation
final String className;
The CSS class name representing the bottom navigation bar style. example: 'navbar__floating'
final String className;