BreakPoint enum

Defines BreakPoint sizes for responsive design.

Inheritance
Available extensions

Values

xs → const BreakPoint

Extra small screens (less than 480px) e.g. mobile phones.

const BreakPoint(kBreakpointXSmall, 'br-xs')
sm → const BreakPoint

Small screens (480px to 576px) e.g. larger phones.

const BreakPoint(kBreakpointSmall, 'br-sm')
md → const BreakPoint

Medium screens (576px to 768px) e.g. tablets.

const BreakPoint(kBreakpointMedium, 'br-md')
lg → const BreakPoint

Large screens (768px to 1024px) e.g. laptops.

const BreakPoint(kBreakpointLarge, 'br-lg')
xl → const BreakPoint

Extra large screens (1024px and above) e.g. desktops.

const BreakPoint(kBreakpointXLarge, 'br-xl')

Properties

className → String
The CSS class name.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
The width in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

desktop → BreakPoint
Breakpoint for desktops (1024px and above).
no setter
laptop → BreakPoint
Breakpoint for laptops (768px to 1024px).
no setter
largerPhone → BreakPoint
Breakpoint for larger phones (480px to 576px).
no setter
mobile → BreakPoint
Breakpoint for mobile phones (less than 480px).
no setter
tablet → BreakPoint
Breakpoint for tablets (576px to 768px).
no setter

Constants

values → const List<BreakPoint>
A constant List of the values in this enum, in order of their declaration.