CarouselAlignment enum

Defines the alignment of items in a carousel view.

Inheritance
Available extensions

Values

start → const CarouselAlignment

Align items to the start of the scroll view.

center → const CarouselAlignment

Center items within the scroll view.

end → const CarouselAlignment

Align items to the end of the scroll view.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CarouselAlignment>
A constant List of the values in this enum, in order of their declaration.