CrossAxisAlignment enum

How the children within a Flex container (Row or Column) should be placed along the cross axis.

Inheritance
Available extensions

Values

start → const CrossAxisAlignment

Place the children with their start edges aligned with the start side of the cross axis.

end → const CrossAxisAlignment

Place the children as close to the end of the cross axis as possible.

center → const CrossAxisAlignment

Place the children aligned with the middle of the cross axis.

stretch → const CrossAxisAlignment

Require the children to fill the cross axis.

baseline → const CrossAxisAlignment

Align the children along their baselines.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CrossAxisAlignment>
A constant List of the values in this enum, in order of their declaration.