DropdownItem<T> class

Represents a single item in the Dropdown component.

Constructors

const

Properties

disabled → bool
Cannot be selected if section or placeholder is true.
final
hashCode → int
The hash code for this object.
no setteroverride
label → String?
The display text of the item.
final
placeholder → bool
If true, the item will be displayed as a placeholder (not selectable).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section → bool
If true, the item will be displayed as a section header (not selectable).
final
selected → bool
If true, the item will be visually highlighted.
final
value → T?
The value of the item (usually a string or int).
final

Methods

copyWith({T? value, String? label, bool? selected, bool? section, bool? placeholder}) → DropdownItem<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns the string representation of the item value. If the value is null, it returns the label, or 'n/a' if label is null.
override

Operators

operator ==(Object other) → bool
The equality operator.
override