FixedColumnWidth class
Column width fixed to a specific size.
- Inheritance
-
- Object
- TableColumnWidth
- FixedColumnWidth
Constructors
- FixedColumnWidth(Dim width)
-
Creates a column width fixed to a specific size.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited