FractionColumnWidth class

Column width calculated as a fraction of the total table width.

Inheritance

Constructors

FractionColumnWidth(double value)
Creates a column width calculated as a fraction of the total table width.
const

Properties

cssWidth → String
Returns the CSS width string corresponding to this column width rule.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
Fraction value between 0.0 and 1.0.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited