onFocusIn property
Callback invoked when focus moves into the element or any descendant.
Implementation
final void Function(FocusEvent e)? onFocusIn;
Callback invoked when focus moves into the element or any descendant.
final void Function(FocusEvent e)? onFocusIn;