onFocusOut property
Callback invoked when focus moves out of the element or any descendant.
Implementation
final void Function(FocusEvent e)? onFocusOut;
Callback invoked when focus moves out of the element or any descendant.
final void Function(FocusEvent e)? onFocusOut;