onMouseEnter property
Callback invoked when the mouse cursor enters the element.
Implementation
final void Function(MouseEvent e)? onMouseEnter;
Callback invoked when the mouse cursor enters the element.
final void Function(MouseEvent e)? onMouseEnter;