onMouseLeave property
void Function(MouseEvent e)?
onMouseLeave
final
Callback invoked when the mouse cursor leaves the element.
Implementation
final void Function(MouseEvent e)? onMouseLeave;
Callback invoked when the mouse cursor leaves the element.
final void Function(MouseEvent e)? onMouseLeave;