onPointerEnter property
Callback invoked when a pointer enters the element boundaries.
Implementation
final void Function(PointerEvent e)? onPointerEnter;
Callback invoked when a pointer enters the element boundaries.
final void Function(PointerEvent e)? onPointerEnter;