onPointerLeave property
Callback invoked when a pointer leaves the element boundaries.
Implementation
final void Function(PointerEvent e)? onPointerLeave;
Callback invoked when a pointer leaves the element boundaries.
final void Function(PointerEvent e)? onPointerLeave;