onPointerMove property
Callback invoked when a pointer moves across the element.
Implementation
final void Function(PointerEvent e)? onPointerMove;
Callback invoked when a pointer moves across the element.
final void Function(PointerEvent e)? onPointerMove;