onPointerOut property
Callback invoked when a pointer is moved out of the element or its descendants.
Implementation
final void Function(PointerEvent e)? onPointerOut;
Callback invoked when a pointer is moved out of the element or its descendants.
final void Function(PointerEvent e)? onPointerOut;