onPointerOver property
Callback invoked when a pointer is moved onto the element or its descendants.
Implementation
final void Function(PointerEvent e)? onPointerOver;
Callback invoked when a pointer is moved onto the element or its descendants.
final void Function(PointerEvent e)? onPointerOver;