visitChildren abstract method
Walks this span and all nested child spans in pre-order traversal.
Stops recursion early if visitor returns false.
Implementation
bool visitChildren(bool Function(InlineSpan span) visitor);
Walks this span and all nested child spans in pre-order traversal.
Stops recursion early if visitor returns false.
bool visitChildren(bool Function(InlineSpan span) visitor);