IntrinsicColumnWidth class
Column width based on the intrinsic content width.
- Inheritance
-
- Object
- TableColumnWidth
- IntrinsicColumnWidth
Constructors
- IntrinsicColumnWidth()
-
Creates a column width based on the intrinsic content width.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited