LinearGradientDirection enum

Defines direction for linear gradients.

Inheritance
Available extensions

Values

toTop → const LinearGradientDirection

Gradients towards the top (to top).

const LinearGradientDirection('to top')
toBottom → const LinearGradientDirection

Gradients towards the bottom (to bottom).

const LinearGradientDirection('to bottom')
toLeft → const LinearGradientDirection

Gradients towards the left (to left).

const LinearGradientDirection('to left')
toRight → const LinearGradientDirection

Gradients towards the right (to right).

const LinearGradientDirection('to right')
toTopLeft → const LinearGradientDirection

Gradients towards the top-left corner (to top left).

const LinearGradientDirection('to top left')
toTopRight → const LinearGradientDirection

Gradients towards the top-right corner (to top right).

const LinearGradientDirection('to top right')
toBottomLeft → const LinearGradientDirection

Gradients towards the bottom-left corner (to bottom left).

const LinearGradientDirection('to bottom left')
toBottomRight → const LinearGradientDirection

Gradients towards the bottom-right corner (to bottom right).

const LinearGradientDirection('to bottom right')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The standard CSS direction value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LinearGradientDirection>
A constant List of the values in this enum, in order of their declaration.