cancel static method

void cancel(
  1. String tag
)

Cancels the active debounce operation for tag without executing its callback.

Does nothing if there is no active operation for tag.

Implementation

static void cancel(String tag) {
  final operation = _operations[tag];
  if (operation == null) return;
  operation.timer.cancel();
  _operations.remove(tag);
}