count property
int
get
count
Returns the number of active debounce operations that are currently pending.
Implementation
static int get count => _operations.length;
Returns the number of active debounce operations that are currently pending.
static int get count => _operations.length;