fire static method

void fire(
  1. String tag
)

Immediately executes the callback associated with tag and cancels its timer.

Does nothing if there is no active operation for tag.

Implementation

static void fire(String tag) {
  final operation = _operations[tag];
  if (operation == null) return;
  operation.timer.cancel();
  _operations.remove(tag);
  operation.callback();
}