NakiStatelessMixin mixin

Mixin on StatelessComponent that provides post-render rendering callback hooks (client-side only).

Usage:

class MyComp extends StatelessComponent with NakiStatelessMixin {
  @override
  FutureOr<VoidCallback?> afterRender(BuildContext context) {
    print('rendered!');
    return () => print('cleanup!');
  }

  @override
  Component build(BuildContext context) => ...;
}
Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

afterRender(BuildContext context) → FutureOr<VoidCallback?>
This method is called only once after the component is built and the browser has rendered it. Does nothing on server rendering.
build(BuildContext context) → Component
Describes the part of the user interface represented by this component.
inherited
createElement() → Element
Creates a StatelessElement to manage this component's location in the tree.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) → bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited