afterRender method
This method is called only once after the component is built and the browser has rendered it. Does nothing on server rendering.
Override to perform actions after the component has fully painted.
Can return a cleanup function to be executed when the component is unmounted.
Implementation
FutureOr<VoidCallback?> afterRender(BuildContext context) => null;