NeverScrollableScrollPhysics class

Scroll physics that prevents user scrolling.

Inheritance

Constructors

NeverScrollableScrollPhysics()
Creates a scroll physics that prevents user scrolling.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ScrollPhysicsType
Gets the physics type enumeration.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
props(ScrollDirection direction) → Map<String, String>
Returns CSS properties corresponding to this physics rule.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited