OverlayRegion class
A component that acts as a DOM portal container where all active OverlayScope
child components (modals, dialogs, drawers, tooltips) are rendered.
Note:
NakiAppandScaffoldautomatically include anOverlayRegion. You only need to declare this manually if you are building a custom application shell withoutNakiApporScaffold.
Constructors
- OverlayRegion({Key? key})
-
A component that acts as a DOM portal container where all active
OverlayScopechild components (modals, dialogs, drawers, tooltips) are rendered.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component - Describes the part of the user interface represented by this component.
-
createElement(
) → Element -
Creates a
StatelessElementto manage this component's location in the tree.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited