OverlayRegion constructor

const OverlayRegion({
  1. Key? key,
})

A component that acts as a DOM portal container where all active OverlayScope child components (modals, dialogs, drawers, tooltips) are rendered.

Note: NakiApp and Scaffold automatically include an OverlayRegion. You only need to declare this manually if you are building a custom application shell without NakiApp or Scaffold.

Implementation

const OverlayRegion({super.key});