viewportFraction property
The fraction of the viewport that each page should occupy (default 1.0).
Implementation
final double viewportFraction;
The fraction of the viewport that each page should occupy (default 1.0).
final double viewportFraction;