Placement enum

Represents placement/position of a component relative to another.

Inheritance
Available extensions

Values

top → const Placement

Place above another component.

Place to the right of another component.

bottom → const Placement

Place below another component.

left → const Placement

Place to the left of another component.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Placement>
A constant List of the values in this enum, in order of their declaration.