PopoverPosition enum

Placement position for Popover relative to its target.

Inheritance
Available extensions

Values

top → const PopoverPosition

Popover appears above the target component.

bottom → const PopoverPosition

Popover appears below the target component.

left → const PopoverPosition

Popover appears to the left of the target component.

Popover appears to the right of the target component.

topLeft → const PopoverPosition

Popover appears above and to the left of the target component.

topRight → const PopoverPosition

Popover appears above and to the right of the target component.

bottomLeft → const PopoverPosition

Popover appears below and to the left of the target component.

bottomRight → const PopoverPosition

Popover appears below and to the right of the target component.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The CSS value representing the popover position.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PopoverPosition>
A constant List of the values in this enum, in order of their declaration.