RadialGradientPosition enum

Defines center position for radial gradients.

Inheritance
Available extensions

Values

center → const RadialGradientPosition

Centered position (center).

const RadialGradientPosition('center')
top → const RadialGradientPosition

Top center position (top).

const RadialGradientPosition('top')
bottom → const RadialGradientPosition

Bottom center position (bottom).

const RadialGradientPosition('bottom')
left → const RadialGradientPosition

Left center position (left).

const RadialGradientPosition('left')

Right center position (right).

const RadialGradientPosition('right')
topLeft → const RadialGradientPosition

Top-left corner (top left).

const RadialGradientPosition('top left')
topRight → const RadialGradientPosition

Top-right corner (top right).

const RadialGradientPosition('top right')
bottomLeft → const RadialGradientPosition

Bottom-left corner (bottom left).

const RadialGradientPosition('bottom left')
bottomRight → const RadialGradientPosition

Bottom-right corner (bottom right).

const RadialGradientPosition('bottom right')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The standard CSS position value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RadialGradientPosition>
A constant List of the values in this enum, in order of their declaration.