SEO class
A helper class to represent SEO tags for a page.
Constructors
Properties
- description → String?
-
Page description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keywords
→ List<
String> ? -
Keywords for search engines.
final
- logo → String?
-
Logo url (e.g. 'https://www.example.com/image.jpg').
final
-
robots
→ List<
String> ? -
SEO robots directives (e.g.
'index', 'follow').final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Image displayed on social media platforms.
final
-
Page description displayed on social media platforms.
final
-
Page title displayed on social media platforms.
final
- title → String?
-
Page title (e.g. 'Home | My Awesome Site').
final
- url → String?
-
Page url (e.g. 'https://www.example.com').
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited