hasClients property
bool
get
hasClients
Returns true if the controller is attached to an HTML DOM element.
Implementation
bool get hasClients => _attachedElement != null;
Returns true if the controller is attached to an HTML DOM element.
bool get hasClients => _attachedElement != null;