hasReachedEnd property
bool
get
hasReachedEnd
Returns true if the controller has reached the end of the scrollable component.
Implementation
bool get hasReachedEnd => offset >= maxScrollExtent;
Returns true if the controller has reached the end of the scrollable component.
bool get hasReachedEnd => offset >= maxScrollExtent;