isAtStart property
bool
get
isAtStart
Returns true if the controller is at the start of the scrollable component.
Implementation
bool get isAtStart => offset <= minScrollExtent;
Returns true if the controller is at the start of the scrollable component.
bool get isAtStart => offset <= minScrollExtent;