scrollToEnd method

void scrollToEnd()

Jumps the scroll position to the end of the scrollable component.

In a vertical scroll component this will scroll to the bottom of the scrollable component. In a horizontal scroll component this will scroll to the right end of the scrollable component.

If the scrollable component's children are in reversed order, this method will scroll to the top or left end of the scrollable component based on scroll direction.

Example

final scrollController = ScrollController();
scrollController.scrollToEnd();

Implementation

void scrollToEnd() => jumpTo(maxScrollExtent);