SegmentedInputType enum
Defines the allowed input character types for SegmentedInput component.
Values
- number → const SegmentedInputType
-
Numeric input only (digits 0-9). Recommended for OTP/PIN fields.
- text → const SegmentedInputType
-
Alphanumeric input (any single text character).
- password → const SegmentedInputType
-
Obscured input for sensitive codes or password PINs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SegmentedInputType> - A constant List of the values in this enum, in order of their declaration.