Shape enum
Defines geometric shape types for components, gradients, and clippings.
Values
- circle → const Shape
-
Circular shape (
circle).const Shape('circle') - ellipse → const Shape
-
Elliptical shape (
ellipse).const Shape('ellipse') - rectangle → const Shape
-
Rectangular shape (
rectangle).const Shape('rectangle') - square → const Shape
-
Square shape (
square).const Shape('square') - pill → const Shape
-
Pill/capsule shape (
pill).const Shape('pill') - triangle → const Shape
-
Triangle shape (
triangle).const Shape('triangle')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The standard CSS value representing the shape.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited