SliverGridDelegateWithFixedCrossAxisCount class

Creates grid layouts with a fixed number of tiles in the cross ScrollDirection.

Inheritance

Constructors

SliverGridDelegateWithFixedCrossAxisCount({required int crossAxisCount, Dim mainAxisSpacing = const Dim.px(16), Dim crossAxisSpacing = const Dim.px(16), AspectRatioType childAspectRatio = AspectRatioType.ratio1_1, Dim? mainAxisExtent})
Creates a SliverGridDelegateWithFixedCrossAxisCount.
const

Properties

childAspectRatio → AspectRatioType
Ratio of the cross-axis to the main-axis extent of each child.
final
crossAxisCount → int
Number of columns/rows in the cross ScrollDirection.
final
crossAxisSpacing → Dim
Logical spacing between items along the cross ScrollDirection.
final
hashCode → int
The hash code for this object.
no setterinherited
mainAxisExtent → Dim?
Main axis size of child (overrides childAspectRatio if specified).
final
mainAxisSpacing → Dim
Logical spacing between items along the main ScrollDirection.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited