maxCrossAxisExtent property

Dim maxCrossAxisExtent
final

Maximum extent of tiles in the cross ScrollDirection.

  • If scroll direction is vertical, this is the max-width of each item.
  • If scroll direction is horizontal, this is the max-height of each item.

Implementation

final Dim maxCrossAxisExtent;