SnackbarPosition enum

Screen positioning for Snackbar component.

Inheritance
Available extensions

Values

top → const SnackbarPosition

Top center of the screen.

const SnackbarPosition('sb-top')
bottom → const SnackbarPosition

Bottom center of the screen.

const SnackbarPosition('sb-bottom')
topLeft → const SnackbarPosition

Top left of the screen.

const SnackbarPosition('sb-top-left')
topRight → const SnackbarPosition

Top right of the screen.

const SnackbarPosition('sb-top-right')
bottomLeft → const SnackbarPosition

Bottom left of the screen.

const SnackbarPosition('sb-bottom-left')
bottomRight → const SnackbarPosition

Bottom right of the screen.

const SnackbarPosition('sb-bottom-right')

Properties

className → String
The standard CSS class name representing the snackbar position.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SnackbarPosition>
A constant List of the values in this enum, in order of their declaration.