SnappingScrollPhysics constructor
const
SnappingScrollPhysics()
Creates a scroll physics that snaps scrolling to the nearest item.
Implementation
const SnappingScrollPhysics();
Creates a scroll physics that snaps scrolling to the nearest item.
const SnappingScrollPhysics();