horizontalInside property
Border applied horizontally between rows (rendered as the bottom border of each cell, excluding the final row).
Implementation
final BorderSideData horizontalInside;
Border applied horizontally between rows (rendered as the bottom border of each cell, excluding the final row).
final BorderSideData horizontalInside;