verticalInside property
Border applied vertically between columns (rendered as the right border of each cell, excluding the final column).
Implementation
final BorderSideData verticalInside;
Border applied vertically between columns (rendered as the right border of each cell, excluding the final column).
final BorderSideData verticalInside;