TableColumnWidth class abstract
Base class for specifying column width behavior in a TableView component.
Constructors
- TableColumnWidth()
-
Base const constructor.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited