cssWidth property
String
get
cssWidth
Returns the CSS width string corresponding to this column width rule.
Implementation
String get cssWidth;
Returns the CSS width string corresponding to this column width rule.
String get cssWidth;