TableRow class
A row of cells within a TableView component.
Constructors
Properties
- alignment → TableRowCellAlignment?
-
Alignment of cells in the row.
final
-
children
→ List<
Component> -
Child cell components in the row (e.g. NakiText).
final
- classes → String?
-
Additional CSS classes applied to the row.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Unique identifier for the row.
final
- onClick → VoidCallback?
-
Callback function that is invoked when the row is clicked.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited