BorderData class

Border attributes of a component.

Constructors

BorderData({Color color = Colors.transparent, BorderStyle style = BorderStyle.solid, Dim width = const Dim.px(1), BorderRadiusData? radius, BorderSideData? top, BorderSideData? right, BorderSideData? bottom, BorderSideData? left})
Create a new uniform or directional border.
const
BorderData.only({BorderSideData? top, BorderSideData? right, BorderSideData? bottom, BorderSideData? left, BorderRadiusData? radius})
Creates a border with only the specified borders and radius.
const

Properties

bottom → BorderSideData?
Bottom Border.
final
color → Color
Border color.
final
cssText → String
Returns the CSS text from the style properties.
no setter
hashCode → int
The hash code for this object.
no setteroverride
left → BorderSideData?
Left Border.
final
props → Map<String, String>
Convert border attributes to CSS styles.
no setter
radius → BorderRadiusData?
Border radius.
final
Right Border.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → BorderStyle
Border style (e.g. solid, dashed, dotted, double, groove, ridge).
final
top → BorderSideData?
Top Border.
final
width → Dim
Border width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

none → BorderData
A border with all properties set to zero/none.
no setter