BorderRadiusData class

Border radius attributes of a component.

Constructors

BorderRadiusData({Dim? topLeft, Dim? topRight, Dim? bottomLeft, Dim? bottomRight})
Create a new radius.
const
BorderRadiusData.all(Dim value)
Create a symmetric border radius.
factory

Properties

bottomLeft → Dim?
Bottom-left radius.
final
bottomRight → Dim?
Bottom-right radius.
final
cssText → String
Returns the CSS text from the style properties.
no setter
hashCode → int
The hash code for this object.
no setteroverride
props → Map<String, String>
Convert radius attributes to CSS styles.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeft → Dim?
Top-left radius.
final
topRight → Dim?
Top-right radius.
final
value → String?
Returns the CSS value of the border radius.
no setter

Methods

copyWith({Dim? topLeft, Dim? topRight, Dim? bottomLeft, Dim? bottomRight}) → BorderRadiusData
Create a new radius with optional changes to corner values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

squircle → BorderRadiusData
iOS-style squircle border radius.
no setter

Constants

circular → const BorderRadiusData
Circular border radius.
none → const BorderRadiusData
A radius with all corners set to zero.