BorderScheme class

Represents customizable global border color and width variables.

Constructors

BorderScheme({Color? borderColor, Dim? borderWidth, Dim? fieldHoverBorderWidth, Dim? focusBorderWidth, Dim? errorBorderWidth})
const

Properties

borderColor → Color?
Default border color.
final
borderWidth → Dim?
Default border width.
final
errorBorderWidth → Dim?
Error border width.
final
fieldHoverBorderWidth → Dim?
Field hover border width.
final
focusBorderWidth → Dim?
Focus border width.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? borderColor, Dim? borderWidth, Dim? fieldHoverBorderWidth, Dim? focusBorderWidth, Dim? errorBorderWidth}) → BorderScheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override