ColorSeed class

Represents customizable base and semantic color variables.

Constructors

ColorSeed({Color? primary, Color? secondary, Color? accent, Color? green, Color? yellow, Color? red, Color? baseTextColor, Color? placeholderColor, Color? mutedColor, Color? subtitleColor, Color? selectedItemColor, Color? selectedTextBackgroundColor, Color? selectedTextColor, Color? selectedItemBackgroundColor, Color? backgroundColor, Color? errorColor, Color? successColor, Color? warningColor, Color? infoColor, Color? errorWeakColor, Color? successWeakColor, Color? warningWeakColor, Color? infoWeakColor, Color? surfaceVariantColor, Color? surfaceMutedColor, Color? focusBorderColor, Color? hoverColor, Color? disabledBackgroundColor, Color? disabledColor})
const

Properties

accent → Color?
Accent color.
final
backgroundColor → Color?
Root background color.
final
baseTextColor → Color?
Base text color.
final
disabledBackgroundColor → Color?
Background color for disabled components.
final
disabledColor → Color?
Color for disabled components.
final
errorColor → Color?
Error state color.
final
errorWeakColor → Color?
Weak background color for error callouts.
final
focusBorderColor → Color?
Border color for focused components.
final
green → Color?
Accent green color.
final
hashCode → int
The hash code for this object.
no setteroverride
hoverColor → Color?
Hover color for components.
final
infoColor → Color?
Info state color.
final
infoWeakColor → Color?
Weak background color for info callouts.
final
mutedColor → Color?
Muted background/foreground color.
final
placeholderColor → Color?
Default text placeholder color.
final
primary → Color?
Primary color.
final
red → Color?
Accent red color.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondary → Color?
Secondary color.
final
selectedItemBackgroundColor → Color?
Selected item background color for dropdown items.
final
selectedItemColor → Color?
Selected item color for dropdowns and list items.
final
selectedTextBackgroundColor → Color?
Selected text background color.
final
selectedTextColor → Color?
Selected text color.
final
subtitleColor → Color?
Subtitle or secondary text color.
final
successColor → Color?
Success state color.
final
successWeakColor → Color?
Weak background color for success callouts.
final
surfaceMutedColor → Color?
Muted background color for container surfaces.
final
surfaceVariantColor → Color?
Secondary surface background color variation.
final
warningColor → Color?
Warning state color.
final
warningWeakColor → Color?
Weak background color for warning callouts.
final
yellow → Color?
Accent yellow color.
final

Methods

copyWith({Color? primary, Color? secondary, Color? accent, Color? green, Color? yellow, Color? red, Color? baseTextColor, Color? placeholderColor, Color? mutedColor, Color? subtitleColor, Color? selectedItemColor, Color? selectedTextBackgroundColor, Color? selectedTextColor, Color? selectedItemBackgroundColor, Color? backgroundColor, Color? errorColor, Color? successColor, Color? warningColor, Color? infoColor, Color? errorWeakColor, Color? successWeakColor, Color? warningWeakColor, Color? infoWeakColor, Color? surfaceVariantColor, Color? surfaceMutedColor, Color? focusBorderColor, Color? hoverColor, Color? disabledBackgroundColor, Color? disabledColor}) → ColorSeed
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override