ComponentScheme class

Represents customizable variables for Naki components.

Constructors

ComponentScheme({int? textMaxLines, Dim? inputHeight, Color? inputTextColor, Color? labelColor, Dim? fontSizeInput, Color? fieldBackgroundColor, Color? fieldHoverColor, Color? buttonBackgroundColor, Color? buttonColor, Dim? buttonHeight, Dim? buttonWidth, Dim? dropdownHeight, Dim? dropdownWidth, Dim? dropdownMenuHeight, Color? dropdownMenuBackgroundColor, Dim? dropdownOptionFontSize, Dim? dropdownOptionPadding, Dim? spinnerSize, Dim? spinnerBorderWidth, Color? spinnerTrackColor, Color? spinnerColor, Color? spinnerBladeColor, Color? spinnerSurfaceColor, Color? sliderThumbColor, Color? sliderTrackColor, Dim? sliderThumbSize, Color? switchThumbColor, Dim? radioButtonRadius, Color? radioButtonColor, Color? appbarBackgroundColor, Dim? appbarHeight, Color? bottomNavbarBackgroundColor, Dim? bottomNavbarHeight, Dim? carouselItemExtent, Dim? carouselGap, Color? tableHeaderBackgroundColor, Color? tableHeaderBorderColor, Color? tableRowHoverColor, Dim? gridGap, Color? snackbarBackgroundColor, Color? snackbarForegroundColor, Dim? snackbarBorderRadius, Color? bannerBackgroundColor, Color? bannerForegroundColor, Dim? bannerBorderRadius, Color? bannerBorderColor, Color? tooltipBackgroundColor, Color? tooltipTextColor, Dim? tooltipBorderRadius, Dim? tooltipFontSize, Color? popoverBackgroundColor, Color? popoverTextColor, Color? popoverBorderColor, Dim? popoverBorderRadius, Color? dialogBackgroundColor, Dim? dialogBorderRadius, Color? dialogBarrierBackgroundColor, Color? drawerBackgroundColor, Dim? drawerWidth, Color? drawerBarrierBackgroundColor, Color? bottomSheetBackgroundColor, Dim? bottomSheetMaxHeight, Color? bottomSheetBarrierBackgroundColor, Color? buttonHoverBgColor})
const

Properties

appbarBackgroundColor → Color?
Appbar background color.
final
appbarHeight → Dim?
Appbar height.
final
bannerBackgroundColor → Color?
Banner background color.
final
bannerBorderColor → Color?
Banner border color.
final
bannerBorderRadius → Dim?
Banner border radius.
final
bannerForegroundColor → Color?
Banner foreground color.
final
bottomNavbarBackgroundColor → Color?
Bottom navbar background color.
final
bottomNavbarHeight → Dim?
Bottom navbar height.
final
bottomSheetBackgroundColor → Color?
Bottom sheet background color.
final
bottomSheetBarrierBackgroundColor → Color?
Bottom sheet barrier backdrop color.
final
bottomSheetMaxHeight → Dim?
Bottom sheet max height.
final
buttonBackgroundColor → Color?
Button background color.
final
buttonColor → Color?
Button text color.
final
buttonHeight → Dim?
Button height.
final
buttonHoverBgColor → Color?
Button hover background color.
final
buttonWidth → Dim?
Button width.
final
carouselGap → Dim?
Carousel gap.
final
carouselItemExtent → Dim?
Carousel item extent.
final
dialogBackgroundColor → Color?
Dialog background color.
final
dialogBarrierBackgroundColor → Color?
Dialog barrier backdrop color.
final
dialogBorderRadius → Dim?
Dialog border radius.
final
drawerBackgroundColor → Color?
Drawer background color.
final
drawerBarrierBackgroundColor → Color?
Drawer barrier backdrop color.
final
drawerWidth → Dim?
Drawer width.
final
Dropdown default trigger height.
final
Dropdown menu background color.
final
Dropdown menu height.
final
Dropdown option font size.
final
Dropdown option padding.
final
Dropdown default trigger width.
final
fieldBackgroundColor → Color?
Input background color.
final
fieldHoverColor → Color?
Input hover border color.
final
fontSizeInput → Dim?
Input font size.
final
gridGap → Dim?
Grid gap.
final
hashCode → int
The hash code for this object.
no setteroverride
inputHeight → Dim?
Input height for TextField, Dropdown, etc.
final
inputTextColor → Color?
Input text color.
final
labelColor → Color?
Label color.
final
popoverBackgroundColor → Color?
Popover background color.
final
popoverBorderColor → Color?
Popover border color.
final
popoverBorderRadius → Dim?
Popover border radius.
final
popoverTextColor → Color?
Popover text color.
final
radioButtonColor → Color?
Radio button color.
final
radioButtonRadius → Dim?
Radio button radius.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliderThumbColor → Color?
Slider thumb color.
final
sliderThumbSize → Dim?
Slider thumb size.
final
sliderTrackColor → Color?
Slider track color.
final
snackbarBackgroundColor → Color?
Snackbar background color.
final
snackbarBorderRadius → Dim?
Snackbar border radius.
final
snackbarForegroundColor → Color?
Snackbar foreground color.
final
spinnerBladeColor → Color?
Spinner blade color (for iOS spinner style).
final
spinnerBorderWidth → Dim?
Spinner border width.
final
spinnerColor → Color?
Spinner color.
final
spinnerSize → Dim?
Spinner size.
final
spinnerSurfaceColor → Color?
Spinner surface color (for glassmorphism spinner style).
final
spinnerTrackColor → Color?
Spinner track color.
final
switchThumbColor → Color?
Switch thumb color.
final
tableHeaderBackgroundColor → Color?
Table header background color.
final
tableHeaderBorderColor → Color?
Table header border color.
final
tableRowHoverColor → Color?
Table row hover background color.
final
textMaxLines → int?
Text max lines.
final
tooltipBackgroundColor → Color?
Tooltip background color.
final
tooltipBorderRadius → Dim?
Tooltip border radius.
final
tooltipFontSize → Dim?
Tooltip font size.
final
tooltipTextColor → Color?
Tooltip text color.
final

Methods

copyWith({int? textMaxLines, Dim? inputHeight, Color? inputTextColor, Color? labelColor, Dim? fontSizeInput, Color? fieldBackgroundColor, Color? fieldHoverColor, Color? buttonBackgroundColor, Color? buttonColor, Color? buttonHoverBgColor, Dim? buttonHeight, Dim? buttonWidth, Dim? dropdownHeight, Dim? dropdownWidth, Dim? dropdownMenuHeight, Color? dropdownMenuBackgroundColor, Dim? dropdownOptionFontSize, Dim? dropdownOptionPadding, Dim? spinnerSize, Dim? spinnerBorderWidth, Color? spinnerTrackColor, Color? spinnerColor, Color? spinnerBladeColor, Color? spinnerSurfaceColor, Color? sliderThumbColor, Color? sliderTrackColor, Dim? sliderThumbSize, Color? switchThumbColor, Dim? radioButtonRadius, Color? radioButtonColor, Color? appbarBackgroundColor, Dim? appbarHeight, Color? bottomNavbarBackgroundColor, Dim? bottomNavbarHeight, Dim? carouselItemExtent, Dim? carouselGap, Color? tableHeaderBackgroundColor, Color? tableHeaderBorderColor, Color? tableRowHoverColor, Dim? gridGap, Color? snackbarBackgroundColor, Color? snackbarForegroundColor, Dim? snackbarBorderRadius, Color? bannerBackgroundColor, Color? bannerForegroundColor, Dim? bannerBorderRadius, Color? bannerBorderColor, Color? tooltipBackgroundColor, Color? tooltipTextColor, Dim? tooltipBorderRadius, Dim? tooltipFontSize, Color? popoverBackgroundColor, Color? popoverTextColor, Color? popoverBorderColor, Dim? popoverBorderRadius, Color? dialogBackgroundColor, Dim? dialogBorderRadius, Color? dialogBarrierBackgroundColor, Color? drawerBackgroundColor, Dim? drawerWidth, Color? drawerBarrierBackgroundColor, Color? bottomSheetBackgroundColor, Dim? bottomSheetMaxHeight, Color? bottomSheetBarrierBackgroundColor}) → ComponentScheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override