disabledBackgroundColor property
Color?
disabledBackgroundColor
final
Color applied to the background of a component when disabled.
Implementation
final Color? disabledBackgroundColor;
Color applied to the background of a component when disabled.
final Color? disabledBackgroundColor;