disabledColor property
Color?
disabledColor
final
Color applied to the foreground of a component when disabled.
Implementation
final Color? disabledColor;
Color applied to the foreground of a component when disabled.
final Color? disabledColor;