errorTextColor property
Color?
errorTextColor
final
Color applied to a validation text or error message.
Implementation
final Color? errorTextColor;
Color applied to a validation text or error message.
final Color? errorTextColor;