focusColor property
Color?
focusColor
final
Color applied to the border of a component when focused.
Implementation
final Color? focusColor;
Color applied to the border of a component when focused.
final Color? focusColor;