CssPropsExtension extension

Extension on Map providing CSS property manipulation utilities.

on

Properties

cssText → String

Available on Map<String, String>, provided by the CssPropsExtension extension

Converts raw CSS style properties to inline CSS string.
no setter

Methods

combine(Map<String, String> other) → Map<String, String>

Available on Map<String, String>, provided by the CssPropsExtension extension

Combines this map with other.
delete(String key) → Map<String, String>

Available on Map<String, String>, provided by the CssPropsExtension extension

Deletes key and its value from this map and returns a new map without it.
without(List<String> keys) → Map<String, String>

Available on Map<String, String>, provided by the CssPropsExtension extension

Deletes keys and their values from this map and returns a new map without them.