of static method
Finds the nearest DefaultTextStyle instance in the component tree and returns its style.
If no DefaultTextStyle is found, it returns a TextStyle instance with all properties set to their default values.
Implementation
static TextStyle of(BuildContext context) {
return _of(context)?.style ?? const TextStyle();
}