EdgeInsets class
Represents spacing attributes (margins or paddings) around a component.
Constructors
- EdgeInsets.all(Dim value)
-
Creates spacing where all four sides have the same
value.const - EdgeInsets.only({Dim? top, Dim? right, Dim? bottom, Dim? left})
-
Creates spacing with only the specified sides set.
const
- EdgeInsets.symmetric({Dim? vertical, Dim? horizontal})
-
Creates spacing with symmetrical vertical and horizontal offsets.
const
Properties
- bottom → Dim?
-
Spacing on the bottom side.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- left → Dim?
-
Spacing on the left side.
final
-
mProps
→ Map<
String, String> -
Converts margin attributes to a CSS style map.
no setter
-
pProps
→ Map<
String, String> -
Converts padding attributes to a CSS style map.
no setter
- right → Dim?
-
Spacing on the right side.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → Dim?
-
Spacing on the top side.
final
- value → String?
-
Gets the CSS value of the EdgeInsets.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- zero → const EdgeInsets
- The default zero spacing.