ElevationScheme class

Represents customizable global shadow and elevation color variables.

Constructors

ElevationScheme({Color? shadowColor, Color? smallShadowColor, Color? mediumShadowColor, Color? largeShadowColor})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
largeShadowColor → Color?
Large shadow color.
final
mediumShadowColor → Color?
Medium shadow color.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
Default shadow color.
final
smallShadowColor → Color?
Small shadow color.
final

Methods

copyWith({Color? shadowColor, Color? smallShadowColor, Color? mediumShadowColor, Color? largeShadowColor}) → ElevationScheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override