placeholderText property
The placeholder text displayed in the component, when input value is empty.
Implementation
final String? placeholderText;
The placeholder text displayed in the component, when input value is empty.
final String? placeholderText;