NullishStringExtension extension
Extension on nullable String for null and empty checks.
- on
Properties
- isNotNullAndEmpty → bool
-
Available on String?, provided by the NullishStringExtension extension
Returns true if this string is not null and not empty.no setter - isNullOrEmpty → bool
-
Available on String?, provided by the NullishStringExtension extension
Returns true if this string is null or empty.no setter