SizeConstraints class

Size attributes of a component.

Constructors

SizeConstraints({Dim? width, Dim? height, Dim? minWidth, Dim? minHeight, Dim? maxWidth, Dim? maxHeight})
Create a new size.
const

Properties

cssText → String
Returns the CSS text from the style properties.
no setter
hashCode → int
The hash code for this object.
no setteroverride
height → Dim?
Height.
final
maxHeight → Dim?
Maximum height.
final
maxWidth → Dim?
Maximum width.
final
minHeight → Dim?
Minimum height.
final
minWidth → Dim?
Minimum width.
final
props → Map<String, String>
Convert size attributes to CSS styles.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → Dim?
Width.
final

Methods

combineWith(SizeConstraints? other) → SizeConstraints
Combines this size constraint with another size constraint. other is the constraint that takes precedence.
copyWith({Dim? width, Dim? height, Dim? minWidth, Dim? minHeight, Dim? maxWidth, Dim? maxHeight}) → SizeConstraints
Copy size constrains.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override