decorationLine property
TextDecorationLine?
decorationLine
final
Line decoration to paint on or near the text.
Implementation
final TextDecorationLine? decorationLine;
Line decoration to paint on or near the text.
final TextDecorationLine? decorationLine;