fontFamily property
FontFamily?
fontFamily
final
Font family to use when painting the text (e.g. 'Inter', 'sans-serif').
Implementation
final FontFamily? fontFamily;
Font family to use when painting the text (e.g. 'Inter', 'sans-serif').
final FontFamily? fontFamily;