truncate property
If true, the text will be truncated with an ellipsis if it overflows.
This property is ignored if maxLines is greater than 1.
Implementation
final bool truncate;
If true, the text will be truncated with an ellipsis if it overflows.
This property is ignored if maxLines is greater than 1.
final bool truncate;