framework library

NAKI UI - FRAMEWORK API

Exports framework lifecycle, models, gestures, animations, and utilities.

Classes

AlwaysScrollableScrollPhysics
Scroll physics that always allows scrolling even if content fits.
BottomNavigationBarItem
Represents an item in BottomNavigationBar.items.
BouncingScrollPhysics
Scroll physics that allows bounce effect at boundaries (iOS-style).
BrowserLifecycleListeners
Client-side utility for observing browser and component lifecycle events.
CalendarDay
A calendar day.
CalendarMonth
A calendar month.
ClampingScrollPhysics
Scroll physics that clamps content strictly inside boundaries (Android-style).
Represents a single item in the Dropdown component.
FixedColumnWidth
Column width fixed to a specific size.
FlexColumnWidth
Column width that expands based on flex factor.
FractionColumnWidth
Column width calculated as a fraction of the total table width.
GestureRecognizer
A helper class that simplifies binding DOM gestures and user interaction events to Jaspr and Naki components.
InlineSpan
Abstract class that represents a single inline text span.
InputEvents
A helper class that simplifies binding DOM input, change, select, focus, focusin, focusout, and blur events to input components.
IntrinsicColumnWidth
Column width based on the intrinsic content width.
NakiDebounce
NakiDebounce provides utility methods for debouncing function executions.
NeverScrollableScrollPhysics
Scroll physics that prevents user scrolling.
OverlayController
Controls an overlay component (Dialog, Drawer, BottomSheet, Snackbar, Tooltip, Alert), managing its open/closed visibility state and listener notifications.
OverlayState
Utility class for controlling overlay components
PageController
A controller for a PageView, enabling page-by-page navigation.
PlatformData
Client-side implementation of BrowserPlatform for web browsers.
ScrollBarConfiguration
Scroll bar configuration.
ScrollController
Controls a scrollable component, allowing programmatic scrolling and listening to scroll notifications.
ScrollPhysics
Defines scrolling physics rules for scroll views.
SEO
A helper class to represent SEO tags for a page.
SliverGridDelegate
Controls the layout of tiles in a GridView.
SliverGridDelegateWithFixedCrossAxisCount
Creates grid layouts with a fixed number of tiles in the cross ScrollDirection.
SliverGridDelegateWithMaxCrossAxisExtent
Creates grid layouts with tiles that each have a maximum cross-axis extent.
SnappingScrollPhysics
Scroll physics that snaps scrolling to the nearest item.
TableBorder
Defines horizontal and vertical borders of a Table component.
TableColumnWidth
Base class for specifying column width behavior in a TableView component.
TableRow
A row of cells within a TableView component.

Enums

Alignment
Alignment points relative to a 2D box.
AspectRatioType
Represents standard display aspect ratios.
Autofill
Types of autofill suggestions for input fields.
BannerType
Severity / intent type for Banner component.
Baseline
Represents standard CSS vertical alignment baseline options for inline text and components.
BottomNavigationBarLandscapeLayout
Refines the landscape layout of a bottom navigation bar.
BottomNavigationBarType
Defines BottomNavigationBar type.
BoxFit
How an image should fit within its bounds.
BreakPoint
Defines BreakPoint sizes for responsive design.
Brightness
Controls the overall lighting of a component based on current theme mode or user preference.
CalendarType
Defines Calendar type.
CarouselAlignment
Defines the alignment of items in a carousel view.
ConicGradientPosition
Defines center position for conic gradients.
CrossAxisAlignment
How the children within a Flex container (Row or Column) should be placed along the cross axis.
Curves
Standard animation curves.
DialogPosition
Positioning / alignment option for Dialog component.
Direction
Represents the layout direction of a component.
DrawerPosition
Slide direction / anchor for Drawer component.
FileType
File types.
FlexFit
How a flexible child component sizes itself along the main axis in a Flex container (Row or Column).
FontStyle
Represents the style of glyphs in a font (upright vs. italicized).
GradientType
Defines Gradient type.
LinearGradientDirection
Defines direction for linear gradients.
MainAxisAlignment
How the children within a Flex container (Row or Column) should be placed along the main axis.
MainAxisSize
How much space should be occupied by the main axis in a Flex container (Row or Column).
Orientation
Represents the orientation of the browser viewport or a component.
Placement
Represents placement/position of a component relative to another.
PopoverPosition
Placement position for Popover relative to its target.
RadialGradientPosition
Defines center position for radial gradients.
ScrollDirection
The direction of scrolling.
ScrollPhysicsType
Determines the scrolling physics behavior.
SegmentedInputShape
Represents the visual shape of individual segment fields in SegmentedInput component.
SegmentedInputType
Defines the allowed input character types for SegmentedInput component.
Shape
Defines geometric shape types for components, gradients, and clippings.
SnackbarPosition
Screen positioning for Snackbar component.
TableHeaderCellAlignment
Alignment for table header cells.
TableRowCellAlignment
Alignment of content within a table row cell.
TextDecorationStyle
Represents the style of text decoration lines.
ThemeMode
Theme mode options.
TooltipPosition
Placement position for Tooltip relative to its target.
ValidationPattern
Represents standard HTML input validation regex patterns.

Mixins

NakiStatefulMixin<T extends StatefulComponent>
Mixin on State that provides post-render rendering callback hooks (client-side only).
NakiStatelessMixin
Mixin on StatelessComponent that provides post-render rendering callback hooks (client-side only).

Typedefs

Events = GestureRecognizer
Alias for GestureRecognizer.
Gestures = GestureRecognizer
Alias for GestureRecognizer.
LifecycleCallback = void Function()
LifecycleResizeCallback = void Function(Dim height, Dim width, Orientation orientation)
LifecycleValueCallback<T> = void Function(T value)
Position = Placement
Alias for Placement.