AspectRatioType enum
Represents standard display aspect ratios.
Values
- ratio16_9 → const AspectRatioType
-
16:9 widescreen ratio (e.g. standard HD TVs).
const AspectRatioType('16/9') - ratio4_3 → const AspectRatioType
-
4:3 standard display ratio (e.g. standard definition TVs).
const AspectRatioType('4/3') - ratio1_1 → const AspectRatioType
-
1:1 square ratio (e.g. profile photos).
const AspectRatioType('1/1') - ratio3_2 → const AspectRatioType
-
3:2 standard ratio (e.g. 3x2 or 6x4 photos).
const AspectRatioType('3/2') - ratio9_16 → const AspectRatioType
-
9:16 vertical content ratio (e.g. reels, shorts, stories).
const AspectRatioType('9/16') - ratio4_5 → const AspectRatioType
-
4:5 content ratio (e.g. instagram post).
const AspectRatioType('4/5') - ratio21_9 → const AspectRatioType
-
21:9 cinematic ratio (e.g. ultrawide monitors).
const AspectRatioType('21/9') - ratio1_2 → const AspectRatioType
-
1:2 vertical ratio (e.g. phone screenshots).
const AspectRatioType('1/2')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The standard CSS value representing the ratio type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cinematic → const AspectRatioType
- Suitable for cinematic movies related content.
- instagramPost → const AspectRatioType
- Suitable for Instagram posts related content.
- profile → const AspectRatioType
- Suitable for icons, avatars, logos related content.
- stories → const AspectRatioType
- Suitable for Instagram stories, Instagram reels, YouTube shorts, TikTok videos related content.
-
values
→ const List<
AspectRatioType> - A constant List of the values in this enum, in order of their declaration.
- youtubeVideo → const AspectRatioType
- Suitable for YouTube videos, Twitter videos, LinkedIn videos, Facebook videos related content.