Baseline enum
Represents standard CSS vertical alignment baseline options for inline text and components.
Values
- baseline → const Baseline
-
Aligns the baseline of the element with the baseline of its parent (CSS:
baseline).const Baseline('baseline') - sub → const Baseline
-
Lowers the baseline of the element to the subscript position (CSS:
sub).const Baseline('sub') - super_ → const Baseline
-
Raises the baseline of the element to the superscript position (CSS:
super).const Baseline('super') - top → const Baseline
-
Aligns the top of the element with the top of the line (CSS:
top).const Baseline('top') - textTop → const Baseline
-
Aligns the top of the element with the top of the parent font (CSS:
text-top).const Baseline('text-top') - middle → const Baseline
-
Aligns the middle of the element with the baseline plus half the x-height of the parent (CSS:
middle).const Baseline('middle') - bottom → const Baseline
-
Aligns the bottom of the element with the bottom of the line (CSS:
bottom).const Baseline('bottom') - textBottom → const Baseline
-
Aligns the bottom of the element with the bottom of the parent font (CSS:
text-bottom).const Baseline('text-bottom')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The CSS value representing the vertical alignment type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited