BoxFit enum
How an image should fit within its bounds.
Values
- fill → const BoxFit
-
Fill the target box by distorting the image's aspect ratio.
const BoxFit('fill') - contain → const BoxFit
-
As large as possible while still containing the image within the target box.
const BoxFit('contain') - cover → const BoxFit
-
As small as possible while still covering the entire target box.
const BoxFit('cover') - none → const BoxFit
-
Display the image's source at its natural size.
const BoxFit('none') - scaleDown → const BoxFit
-
Align the image within the target box and, if necessary, scale the image down to fit.
const BoxFit('scale-down')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
The standard CSS value representing the box fit type.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited