CalendarDay class

A calendar day.

Constructors

CalendarDay({required DateTime date, bool isSelected = false, bool isDisabled = false, bool isToday = false})
const

Properties

date → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
isDisabled → bool
final
isSelected → bool
final
isToday → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DateTime? date, bool? isSelected, bool? isDisabled, bool? isToday}) → CalendarDay
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited