ConicGradientPosition enum
Defines center position for conic gradients.
Values
- center → const ConicGradientPosition
-
Centered position (
center).const ConicGradientPosition('center') - top → const ConicGradientPosition
-
Top center position (
top).const ConicGradientPosition('top') - bottom → const ConicGradientPosition
-
Bottom center position (
bottom).const ConicGradientPosition('bottom') - left → const ConicGradientPosition
-
Left center position (
left).const ConicGradientPosition('left') - right → const ConicGradientPosition
-
Right center position (
right).const ConicGradientPosition('right') - topLeft → const ConicGradientPosition
-
Top-left corner (
top left).const ConicGradientPosition('top left') - topRight → const ConicGradientPosition
-
Top-right corner (
top right).const ConicGradientPosition('top right') - bottomLeft → const ConicGradientPosition
-
Bottom-left corner (
bottom left).const ConicGradientPosition('bottom left') - bottomRight → const ConicGradientPosition
-
Bottom-right corner (
bottom right).const ConicGradientPosition('bottom right')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The standard CSS position value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ConicGradientPosition> - A constant List of the values in this enum, in order of their declaration.