Curves enum
Standard animation curves.
Values
- easeInOut → const Curves
-
Standard ease-in-out curve.
Starts slowly, accelerates through the middle, and decelerates towards the end.
const Curves._('ease-in-out') - linear → const Curves
-
Standard linear curve.
Progresses at a uniform speed with a constant rate of change.
const Curves._('linear') - easeIn → const Curves
-
Standard ease-in curve.
Starts slowly and accelerates quadratically towards the end.
const Curves._('ease-in') - easeOut → const Curves
-
Standard ease-out curve.
Starts at higher speed and decelerates quadratically towards the end.
const Curves._('ease-out') - easeInOutBack → const Curves
-
Standard ease-in-out-back curve.
Starts slowly, accelerates through the middle, and decelerates towards the end.
const Curves._('ease-in-out-back') - easeOutBack → const Curves
-
Standard ease-out-back curve.
Starts at higher speed and decelerates quadratically towards the end.
const Curves._('ease-out-back') - bounceIn → const Curves
-
Standard bounce-in curve.
Starts slowly and accelerates quadratically towards the end.
const Curves._('bounce-in') - bounceOut → const Curves
-
Standard bounce-out curve.
Starts at higher speed and decelerates quadratically towards the end.
const Curves._('bounce-out')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
build(
double t) → double - Returns the value of the curve at the given progress.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited