Returns the string representation of the dropdown item value. If the value is null, it returns the label, or 'n/a' if label is null.
@override String toString() => value?.toString() ?? label ?? 'n/a';