FileType enum
File types.
Values
- allImages → const FileType
-
All image files.
const FileType('image/*', 'Images') - allVideos → const FileType
-
All video files.
const FileType('video/*', 'Videos') - allAudios → const FileType
-
All audio files.
const FileType('audio/*', 'Audios') - allDocuments → const FileType
-
All document files.
const FileType('application/*', 'Documents') - allTexts → const FileType
-
All text files.
const FileType('text/*', 'Texts') - txt → const FileType
-
Text file.
const FileType('text/plain', 'TXT') - doc → const FileType
-
Doc file.
const FileType('application/msword', 'DOC') - docx → const FileType
-
Docx file.
const FileType('application/vnd.openxmlformats-officedocument.wordprocessingml.document', 'DOCX') - js → const FileType
-
Js file.
const FileType('application/javascript', 'JS') - json → const FileType
-
Json file.
const FileType('application/json', 'JSON') - css → const FileType
-
Css file.
const FileType('text/css', 'CSS') - html → const FileType
-
Html file.
const FileType('text/html', 'HTML') - csv → const FileType
-
Csv file.
const FileType('text/csv', 'CSV') - pdf → const FileType
-
Pdf file.
const FileType('application/pdf', 'PDF') - xls → const FileType
-
Xls file.
const FileType('application/vnd.ms-excel', 'XLS') - xlsx → const FileType
-
Xlsx file.
const FileType('application/vnd.openxmlformats-officedocument.spreadsheetml.sheet', 'XSLX') - other → const FileType
-
Unknown file type.
const FileType('application/octet-stream', 'Other') - jpeg → const FileType
-
Jpeg file.
const FileType('image/jpeg', 'JPEG') - svg → const FileType
-
Svg file.
const FileType('image/svg+xml', 'SVG') - zip → const FileType
-
Zip file.
const FileType('application/zip', 'ZIP') - wav → const FileType
-
Wav file.
const FileType('audio/wav', 'WAV') - mp3 → const FileType
-
Mp3 file.
const FileType('audio/mpeg', 'MP3') - png → const FileType
-
Png file.
const FileType('image/png', 'PNG') - webp → const FileType
-
WebP file.
const FileType('image/webp', 'WEBP') - gif → const FileType
-
GIF file.
const FileType('image/gif', 'GIF') - jpg → const FileType
-
JPG file.
const FileType('image/jpg', 'JPG') - mp4 → const FileType
-
MP4 file.
const FileType('video/mp4', 'MP4') - mpeg → const FileType
-
Mpeg file.
const FileType('video/mpeg', 'MPEG') - webm → const FileType
-
WebM file.
const FileType('video/webm', 'WEBM') - ogg → const FileType
-
Ogg file.
const FileType('video/ogg', 'OGG')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited