onMouseMove property
void Function(MouseEvent e)?
onMouseMove
final
Callback invoked when the mouse cursor moves within the element.
Implementation
final void Function(MouseEvent e)? onMouseMove;
Callback invoked when the mouse cursor moves within the element.
final void Function(MouseEvent e)? onMouseMove;