GradientType enum
Defines Gradient type.
Values
- linear → const GradientType
-
Linear gradient.
const GradientType('linear-gradient') - radial → const GradientType
-
Radial gradient.
const GradientType('radial-gradient') - conic → const GradientType
-
Conic gradient.
const GradientType('conic-gradient') - repeatingLinear → const GradientType
-
Repeating linear gradient.
const GradientType('repeating-linear-gradient') - repeatingRadial → const GradientType
-
Repeating radial gradient.
const GradientType('repeating-radial-gradient') - repeatingConic → const GradientType
-
Repeating conic gradient.
const GradientType('repeating-conic-gradient')
Properties
- cssName → String
-
The CSS class name representing the gradient style.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cssText(
List< String> stops) → String - Converts the gradient type and stops to a CSS string (e.g., "linear-gradient(to right, red, blue)").
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GradientType> - A constant List of the values in this enum, in order of their declaration.