InlineSpan class abstract
Abstract class that represents a single inline text span.
- Implementers
Constructors
- InlineSpan({TextStyle? style, String? semanticsLabel})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel → String?
-
An optional screen-reader description or ARIA label for this span.
final
- style → TextStyle?
-
Text style of the inline span.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPlainText(
) → String - Flattens this span and its children into a plain text string.
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
bool visitor(InlineSpan span)) → bool -
Walks this span and all nested child spans in pre-order traversal.
Stops recursion early if
visitorreturnsfalse.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited