ObjectFit enum
How a media content (like an image) should fit within its bounds.
Values
- fill → const ObjectFit
-
Fill the target box by distorting the image's aspect ratio.
const ObjectFit('fill') - contain → const ObjectFit
-
As large as possible while still containing the image within the target box.
const ObjectFit('contain') - cover → const ObjectFit
-
As small as possible while still covering the entire target box.
const ObjectFit('cover') - none → const ObjectFit
-
Display the image's source at its natural size.
const ObjectFit('none') - scaleDown → const ObjectFit
-
Align the image within the target box and, if necessary, scale the image down to fit.
const ObjectFit('scale-down')
Properties
- css → String
-
The standard CSS value representing the object-fit type.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited