ObjectPosition enum
How a media content (like an image) should be positioned within its bounds.
Values
- center → const ObjectPosition
-
Positions the media content at its center point.
const ObjectPosition('center') - topCenter → const ObjectPosition
-
Positions the media content at the top edge, centered horizontally.
const ObjectPosition('top center') - bottomCenter → const ObjectPosition
-
Positions the media content at the bottom edge, centered horizontally.
const ObjectPosition('bottom center') - centerLeft → const ObjectPosition
-
Positions the media content at the center of the left edge.
const ObjectPosition('left center') - centerRight → const ObjectPosition
-
Positions the media content at the center of the right edge.
const ObjectPosition('right center') - topLeft → const ObjectPosition
-
Positions the media content at the top-left corner.
const ObjectPosition('top left') - topRight → const ObjectPosition
-
Positions the media content at the top-right corner.
const ObjectPosition('top right') - bottomLeft → const ObjectPosition
-
Positions the media content at the bottom-left corner.
const ObjectPosition('bottom left') - bottomRight → const ObjectPosition
-
Positions the media content at the bottom-right corner.
const ObjectPosition('bottom right')
Properties
- css → String
-
The standard CSS value representing the object-position type.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ObjectPosition> - A constant List of the values in this enum, in order of their declaration.