OverlayState class
Utility class for controlling overlay components
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
close(
OverlayController controller) → void -
Closes the overlay bound to the provided
controller. -
hide(
OverlayController controller) → void -
Hides the overlay bound to
controller. -
open(
OverlayController controller) → void -
Opens the overlay bound to the provided
controller. -
show(
OverlayController controller) → void -
Shows the overlay bound to
controller. -
toggle(
OverlayController controller) → void -
Toggles the open/closed state of the overlay bound to
controller.