ScrollBarConfiguration class
Scroll bar configuration.
Constructors
- ScrollBarConfiguration({required Color thumbColor, required Color trackColor, Color? hoverColor, double? radius, double? width, double? height})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Height of the scroll bar thumb in pixels (for horizontal scrollbar).
final
- hoverColor → Color?
-
Color of the scroll bar thumb when hovered.
final
- radius → double?
-
Border radius of the scroll bar thumb in pixels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbColor → Color
-
Color of the scroll bar thumb.
final
- trackColor → Color
-
Color of the scroll bar track.
final
- width → double?
-
Width of the scroll bar thumb in pixels (for vertical scrollbar).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited