ScrollPhysicsType enum
Determines the scrolling physics behavior.
Values
- adaptive → const ScrollPhysicsType
-
Standard browser scrolling behavior.
const ScrollPhysicsType('adaptive') - neverScrollable → const ScrollPhysicsType
-
Prevents scrolling.
const ScrollPhysicsType('never_scrollable') - bouncing → const ScrollPhysicsType
-
Allows scrolling beyond content bounds with bounce (iOS-like).
const ScrollPhysicsType('bouncing') - clamping → const ScrollPhysicsType
-
Clamps scrolling strictly to content bounds (Android-like).
const ScrollPhysicsType('clamping') - snapping → const ScrollPhysicsType
-
Snaps scrolling to the nearest item.
const ScrollPhysicsType('snapping')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
The CSS value representing the scrolling physics type.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ScrollPhysicsType> - A constant List of the values in this enum, in order of their declaration.