TableBorder class
Defines horizontal and vertical borders of a Table component.
Constructors
- TableBorder({BorderSideData top = BorderSideData.none, BorderSideData right = BorderSideData.none, BorderSideData bottom = BorderSideData.none, BorderSideData left = BorderSideData.none, BorderSideData horizontalInside = BorderSideData.none, BorderSideData verticalInside = BorderSideData.none, BorderRadiusData? borderRadius})
-
Creates a TableBorder with distinct side borders.
const
- TableBorder.all({Dim width = const Dim.px(1), BorderStyle style = BorderStyle.solid, Color? color, BorderRadiusData? borderRadius})
-
Creates a TableBorder where all sides share
the same border properties.
factory
- TableBorder.symmetric({BorderSideData inside = BorderSideData.none, BorderSideData outside = BorderSideData.none})
-
Creates a TableBorder with symmetric outer/inner borders.
factory
Properties
- borderRadius → BorderRadiusData?
-
Border radius of the table.
final
- bottom → BorderSideData
-
Bottom border of the table's outer boundary.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalInside → BorderSideData
-
Border applied horizontally between rows (rendered as
the bottom border of each cell, excluding the final row).
final
- left → BorderSideData
-
Left border of the table's outer boundary.
final
-
props
→ Map<
String, String> -
Returns the CSS border style map for this TableBorder instance.
no setter
- right → BorderSideData
-
Right border of the table's outer boundary.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → BorderSideData
-
Top border of the table's outer boundary.
final
- verticalInside → BorderSideData
-
Border applied vertically between columns (rendered as
the right border of each cell, excluding the final column).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited