TextDecorationStyle enum

Represents the style of text decoration lines.

Inheritance
Available extensions

Values

solid → const TextDecorationStyle

Draw a single solid line.

double → const TextDecorationStyle

Draw a double line.

dotted → const TextDecorationStyle

Draw a dotted line.

dashed → const TextDecorationStyle

Draw a dashed line.

wavy → const TextDecorationStyle

Draw a wavy line.

ridge → const TextDecorationStyle

The border appears raised depending on the border-style and border-color properties.

groove → const TextDecorationStyle

The border appears indented depending on the border-style and border-color properties.

none → const TextDecorationStyle

Display no border.

outset → const TextDecorationStyle

The border appears as if it is coming out of the page.

inset → const TextDecorationStyle

The border appears as if it is going into the page.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TextDecorationStyle>
A constant List of the values in this enum, in order of their declaration.