BorderSideData class
Defines side attributes for a border (width, color, style).
Constructors
- BorderSideData({Color? color, Dim width = const Dim.px(1), BorderStyle style = BorderStyle.solid})
-
Creates a BorderSideData definition.
const
Properties
- color → Color?
-
Color of the border side.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → BorderStyle
-
Style of the border side (solid, dashed, dotted, none, etc.).
final
- value → String
-
Get the border side CSS value.
no setter
- width → Dim
-
Width of the border side.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- none → const BorderSideData
- A border side with no width/border.