BoxDecoration class
Box decoration attributes of a component.
Constructors
- BoxDecoration({Color? backgroundColor, Gradient? gradient, Display? display, Color? color, BorderData? border, BorderRadiusData? borderRadius, EdgeInsets? padding, EdgeInsets? margin, Alignment? alignment, PositionData? position, Shadow? shadow, double? opacity})
-
Create a new box decoration.
const
Properties
- alignment → Alignment?
-
The alignment of the box child.
final
- backgroundColor → Color?
-
The background color of the box.
final
- border → BorderData?
-
The border of the box.
final
- borderRadius → BorderRadiusData?
-
The border radius of the box.
final
- color → Color?
-
The color of the box content.
final
- cssText → String
-
Returns the CSS text from the style properties.
no setter
- display → Display?
-
The display mode of the box.
final
- gradient → Gradient?
-
The background gradient of the box.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- margin → EdgeInsets?
-
The margin of the box exterior.
final
- opacity → double?
-
The opacity of the box.
final
- padding → EdgeInsets?
-
The padding of the box child.
final
- position → PositionData?
-
The position of the box.
final
-
props
→ Map<
String, String> -
Converts box decoration attributes to a CSS style map.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → Shadow?
-
The shadow of the box.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override