ComponentStatesColor class
Color attributes for different states of a component.
Constructors
- ComponentStatesColor({Color? focusColor, Color? hoverColor, Color? hoverBackgroundColor, Color? errorTextColor, Color? disabledBackgroundColor, Color? disabledColor})
-
Create a new state color.
const
Properties
- cssText → String
-
Returns the CSS text from the style properties.
no setter
- disabledBackgroundColor → Color?
-
Color applied to the background of a component when disabled.
final
- disabledColor → Color?
-
Color applied to the foreground of a component when disabled.
final
- errorTextColor → Color?
-
Color applied to a validation text or error message.
final
- focusColor → Color?
-
Color applied to the border of a component when focused.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hoverBackgroundColor → Color?
-
Color applied to the background of a component when hovered.
final
- hoverColor → Color?
-
Color applied to the foreground of a component when hovered.
final
-
props
→ Map<
String, String> -
Converts state colors to a CSS style map of global variables.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? focusColor, Color? hoverColor, Color? hoverBackgroundColor, Color? errorTextColor, Color? disabledBackgroundColor, Color? disabledColor}) → ComponentStatesColor - Create a copy of the state color.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override