CssPropsExtension extension
Extension on Map providing CSS property manipulation utilities.
Properties
Methods
-
combine(
Map< String, String> other) → Map<String, String> -
Available on Map<
Combines this map withString, String> , provided by the CssPropsExtension extensionother. -
delete(
String key) → Map< String, String> -
Available on Map<
DeletesString, String> , provided by the CssPropsExtension extensionkeyand its value from this map and returns a new map without it. -
without(
List< String> keys) → Map<String, String> -
Available on Map<
DeletesString, String> , provided by the CssPropsExtension extensionkeysand their values from this map and returns a new map without them.