DefaultTextStyle class
A Naki component that applies a default style to descendant Naki text components in the component tree.
Constructors
- DefaultTextStyle({Key? key, required Component child, required TextStyle style})
-
A Naki component that applies a default style to descendant Naki text
components in the component tree.
const
Properties
- child → Component
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle
-
The default text style to apply to descendant Naki text components.
final
Methods
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant DefaultTextStyle oldComponent) → bool - Whether the framework should notify components that inherit from this component.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → TextStyle - Finds the nearest DefaultTextStyle instance in the component tree and returns its style.