InputDecoration class
The border, label, hint, and helper text styles used to decorate a Naki input component.
Constructors
- InputDecoration({String? labelText, TextStyle? labelStyle, String? helperText, TextStyle? helperStyle, String? placeholderText, Color? placeholderColor, BorderData? border, Color? hoverBorderColor, Color? focusBorderColor, TextStyle? errorStyle, TextStyle? inputStyle, EdgeInsets? padding, EdgeInsets? margin})
-
Creates an InputDecoration instance.
const
Properties
- border → BorderData?
-
Border decoration of the component.
final
- errorStyle → TextStyle?
-
Style of the error message
(only font size and color applicable).
final
- focusBorderColor → Color?
-
Color of the border when focused.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- helperStyle → TextStyle?
-
Typography style to use for helperText.
final
- helperText → String?
-
Hint text displayed below the component.
final
- hoverBorderColor → Color?
-
Color of the border when hovered.
final
- inputStyle → TextStyle?
-
Style of the input value.
final
- labelStyle → TextStyle?
-
The typography style to use for labelText.
final
- labelText → String?
-
Label text displayed above the component.
final
- margin → EdgeInsets?
-
Margin of the input component.
final
- padding → EdgeInsets?
-
Padding of the input component.
final
- placeholderColor → Color?
-
Color of the placeholder text.
final
- placeholderText → String?
-
The placeholder text displayed in the component,
when input value is empty.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? labelText, TextStyle? labelStyle, String? helperText, TextStyle? helperStyle, String? placeholderText, Color? placeholderColor, BorderData? border, Color? hoverBorderColor, Color? focusBorderColor, TextStyle? errorStyle, TextStyle? inputStyle, EdgeInsets? padding, EdgeInsets? margin}) → InputDecoration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override