enableCache property
Allow theme mode caching and restoration on page loads.
When configuration is provided, this value is ignored and ThemeConfig.cacheThemeMode value is used instead.
Implementation
final bool enableCache;
Allow theme mode caching and restoration on page loads.
When configuration is provided, this value is ignored and ThemeConfig.cacheThemeMode value is used instead.
final bool enableCache;