PositionData class
Position properties of a component.
Constructors
Properties
- bottom → Dim?
-
The bottom position of the component.
final
- cssText → String
-
Returns the CSS text from the style properties.
no setter
-
extra
→ Map<
String, String> ? -
Additional CSS properties (e.g. transform, scale).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- left → Dim?
-
The left position of the component.
final
- overflow → Overflow?
-
The overflow of the component.
final
-
props
→ Map<
String, String> -
Converts position attributes to a CSS style map.
no setter
- right → Dim?
-
The right position of the component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → Dim?
-
The top position of the component.
final
- visibility → Visibility?
-
The visibility of the component.
final
- zIndex → int?
-
The z-index of the component.
final
Methods
-
copyWith(
{Dim? top, Dim? right, Dim? bottom, Dim? left, int? zIndex, Visibility? visibility, Overflow? overflow, Map< String, String> ? extra}) → PositionData - Copy position attributes.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- bottomCenter → const PositionData
- Bottom center position.
- bottomLeft → const PositionData
- Bottom left position.
- bottomRight → const PositionData
- Bottom right position.
- center → const PositionData
- Center position.
- topCenter → const PositionData
- Top center position.
- topLeft → const PositionData
- Top left position.
- topRight → const PositionData
- Top right position.