RadiusScheme class
Represents customizable global border radius variables.
Constructors
- RadiusScheme({Dim? radiusSm, Dim? radiusMd, Dim? radiusLg, Dim? shapeRadius})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- radiusLg → Dim?
-
Large border radius.
final
- radiusMd → Dim?
-
Medium border radius.
final
- radiusSm → Dim?
-
Small border radius.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeRadius → Dim?
-
Container shape radius.
final
Methods
-
copyWith(
{Dim? radiusSm, Dim? radiusMd, Dim? radiusLg, Dim? shapeRadius}) → RadiusScheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override