Shadow class
Shadow attributes of a component.
Constructors
Properties
- blurRadius → double?
-
The blur radius of the shadow (in pixels).
final
- color → Color?
-
The color of the shadow.
final
- cssText → String
-
Returns the CSS text from the style properties.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- offsetX → double?
-
The x-offset of the shadow (in pixels).
final
- offsetY → double?
-
The y-offset of the shadow (in pixels).
final
-
props
→ Map<
String, String> -
Converts shadow attributes to a CSS style map.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spreadRadius → double?
-
The spread radius of the shadow (in pixels).
final
- value → String?
-
Gets the CSS value of the
box-shadowproperty.no setter
Methods
-
copyWith(
{double? offsetX, double? offsetY, double? blurRadius, double? spreadRadius, Color? color}) → Shadow - Creates a copy of the current shadow with optional new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override