SpacingScheme class
Represents customizable global padding and margin spacing variables.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- marginLg → Dim?
-
Large margin.
final
- marginMd → Dim?
-
Medium margin.
final
- marginSm → Dim?
-
Small margin.
final
- paddingLg → Dim?
-
Large padding.
final
- paddingMd → Dim?
-
Medium padding.
final
- paddingSm → Dim?
-
Small padding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Dim? paddingSm, Dim? paddingMd, Dim? paddingLg, Dim? marginSm, Dim? marginMd, Dim? marginLg}) → SpacingScheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override