maxLines property
Maximum lines of text to display. If null, the full text will be rendered, otherwise the text will be truncated with an ellipsis if it overflows more than the allowed lines.
Implementation
final int? maxLines;
Maximum lines of text to display. If null, the full text will be rendered, otherwise the text will be truncated with an ellipsis if it overflows more than the allowed lines.
final int? maxLines;