TypographyScheme class

Represents customizable font family, font size, and font weight variables.

Constructors

TypographyScheme({List<String>? fontFamily, Dim? fontSizeSm, Dim? fontSizeMd, Dim? fontSizeLg, Dim? fontSizeXl, Dim? fontSize2xl, Dim? fontSize3xl, Dim? fontSize4xl, Dim? fontSize5xl, Dim? fontSizeError, Dim? fontSizeHint, Dim? fontSizeLabel, Dim? fontSizeSectionHeader, int? fontWeightNormal, int? fontWeightMedium, int? fontWeightSemiBold, int? fontWeightBold, int? fontWeightSectionHeader})
const

Properties

fontFamily → List<String>?
Font family stack.
final
fontSize2xl → Dim?
2X large title font size.
final
fontSize3xl → Dim?
3X large title font size.
final
fontSize4xl → Dim?
4X large title font size.
final
fontSize5xl → Dim?
5X large title font size.
final
fontSizeError → Dim?
Validation error font size.
final
fontSizeHint → Dim?
Hint font size.
final
fontSizeLabel → Dim?
Label font size.
final
fontSizeLg → Dim?
Large font size.
final
fontSizeMd → Dim?
Medium font size.
final
fontSizeSectionHeader → Dim?
Section header font size.
final
fontSizeSm → Dim?
Small font size.
final
fontSizeXl → Dim?
Extra large font size.
final
fontWeightBold → int?
Bold font weight.
final
fontWeightMedium → int?
Medium font weight.
final
fontWeightNormal → int?
Normal font weight.
final
fontWeightSectionHeader → int?
Section header font weight.
final
fontWeightSemiBold → int?
Semi-bold font weight.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? fontFamily, Dim? fontSizeSm, Dim? fontSizeMd, Dim? fontSizeLg, Dim? fontSizeXl, Dim? fontSize2xl, Dim? fontSize3xl, Dim? fontSize4xl, Dim? fontSize5xl, Dim? fontSizeError, Dim? fontSizeHint, Dim? fontSizeLabel, Dim? fontSizeSectionHeader, int? fontWeightNormal, int? fontWeightMedium, int? fontWeightSemiBold, int? fontWeightBold, int? fontWeightSectionHeader}) → TypographyScheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override